/*
adf4002_fix.c	set ADF4002 to fixed frequency


    Copyright (C) 2022 Marko Cebokli   S57UUU
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <https://www.gnu.org/licenses/>. 


msp430-gcc -Wall -g -mmcu=msp430g2230 adf4002_fix.c -o adf4002_fix.elf
mspdebug rf2500 "prog adf4002_fix.elf"

P1.2 = MUXO (LD)
P1.5 = LE
P1.6 = DATA
P1.7 = CLK

*/

#include  "msp430.h"


//---------------------------------------------------
//bitbang 24bits into ADF4002
void bang24(long d)
{
int i;

P1OUT &= ~BIT5;		//LE down
P1OUT &= ~BIT7;		//CLK down

for (i=23;i>=0;i--)
  {
  if (d & ((long)1<<i))
    P1OUT |= BIT6;		//DATA up
  else
    P1OUT &= ~BIT6;		//DATA down
  P1OUT |= BIT5;		//CLK up
  P1OUT &= ~BIT5;		//CLK down
  }
  
P1OUT |= BIT7;		//LE up
P1OUT &= ~BIT7;		//LE down

}

//***************************************************
int main(void)
{
long i;

WDTCTL = WDTPW + WDTHOLD;                 // Stop WDT
BCSCTL1 = CALBC1_1MHZ;                    // Set DCO
DCOCTL = CALDCO_1MHZ;

P1DIR |= BIT5+BIT6+BIT7;	//LE,DATA,CLK

P1OUT |= BIT2;	//pullup for lock detect 
P1REN |= BIT2;	//disable for other MUXOUT functions

//Ref = 10 MHz  PD = 2MHz  OUT = 26MHz
bang24(0x000093);	//I latch
bang24(0x000092);	//F latch
bang24(0x120014);	//R latch  
bang24(0x000D01);	//N latch 

while (1)	//check for lost lock approx once per second
  {
  if ((P1IN & BIT2)==0)	//lost lock
    {
    bang24(0x000093);	//I latch
    bang24(0x000092);	//F latch
    bang24(0x120014);	//R latch  
    bang24(0x000D01);	//N latch 
    }
//  bang24(0x80000E);	//TEST
  
//  for (i=0;i<1000000;i++) {}	//delay cca 15 sec at 1MHz CPU
  for (i=0;i<66000;i++) {}	//delay cca 1 sec at 1MHz CPU
  }
return 0;
}
